@@ -7,9 +7,10 @@ from PySide6.QtWidgets import  QApplication, QFileDialog, QMainWindow
 
 from scipy import optimize as optim
 import re
-from pyCftool.export import export_fit
-from pyCftool.loadgui import loadUiWidget
-from pyCftool.options import Options_
+from export import export_fit
+from loadgui import loadUiWidget
+from options import Options_
+from pathlib import Path
 
 class function():
     def __init__(self, eq):
@@ -46,7 +47,9 @@ class function():
 class MainWindow(QMainWindow):
     def __init__(self,x,y,weights,local_variables):
         QMainWindow.__init__(self)
-        self.ui = loadUiWidget('pycftoolGUI.ui')
+        this_directory = Path(__file__).parent
+
+        self.ui = loadUiWidget(this_directory / "pycftoolGUI.ui")
         self.setCentralWidget(self.ui)
 
         self.x = x
